
#
# An implementation of the XDG Base Directory Specification
# http://standards.freedesktop.org/basedir-spec/latest/
# 

import os

strict = False

def with_home (partial, exc_text):
    home = os.getenv('HOME')
    if home:
        return partial(home)
    elif strict:
        raise Exception(exc_text)
    else:
        return None

def xdg_data_home():
    rv = os.getenv('XDG_DATA_HOME')
    if rv:
        return rv
    return with_home (lambda home: os.path.join(home, ".local", "share"), "Unable to determine xdg_data_home")

def xdg_config_home():
    rv = os.getenv('XDG_CONFIG_HOME')
    if rv:
        return rv
    return with_home (lambda home: os.path.join(home, ".config"), "Unable to determine xdg_config_home")
    
def xdg_data_dirs():
    dirs = []
    dirname = xdg_data_home()
    if dirname:
        dirs.append(dirname)
    for dirname in os.getenv('XDG_DATA_DIRS', '/usr/local/share:/usr/share').split(':'):
        dirs.append(dirname)
    return dirs

def xdg_config_dirs():
    dirs = []
    dirname = xdg_config_home()
    if dirname:
        dirs.append(dirname)
    for dirname in os.getenv('XDG_DATA_DIRS', '/etc/xdg').split(':'):
        dirs.append(dirname)
    return dirs
    
def xdg_cache_home():
    rv = os.getenv('XDG_CACHE_HOME')
    if rv:
        return rv
    return with_home (lambda home: os.path.join(home, ".cache"), "Unable to determine xdg_cache_home")

###
### vi:expandtab:sw=4:ts=4
###
